@@ -306,6 +306,7 @@ as.character.frmt <- function(x, ...){
   paste0("frmt('", x$expression, "'",
          if_else(!is.null(x$missing), paste0(", missing = ", missing_to_chr(x$missing)), ""),
          if_else(!is.null(x$scientific), paste0(", scientific = ", x$scientific), ""),
+         if_else(!is.null(x$transform), paste0(", transform = ", deparse(x$transform) %>% str_c(collapse = "")), ""),
          ")"
          )
 }
@@ -314,7 +315,9 @@ as.character.frmt <- function(x, ...){
 #' @export
 as.character.frmt_when <- function(x, ...){
   right <- x$frmt_ls %>%
-    map_chr(~f_rhs(.x) %>% as.character())
+    map_chr(~f_rhs(.x) %>%
+              as.character() %>%
+              missing_to_chr())
   left <- x$frmt_ls %>%
     map_chr(~f_lhs(.x)) %>%
     str_c("'", ., "'")
@@ -332,7 +335,7 @@ as.character.frmt_when <- function(x, ...){
 #' @export
 as.character.frmt_combine <- function(x, ...){
   params <- x$frmt_ls %>%
-    map_chr(as.character) %>%
+    map_chr(~as.character(.x) %>% missing_to_chr()) %>%
     str_c(names(x$frmt_ls), " = ", .) %>%
     str_c(collapse = ", ")
   paste0("frmt_combine('", x$expression, "', ",
